@@ -18,7 +18,7 @@ def split(sep, s):
 
 
 def split_re(pat):
-    ''' creates a partial function that will split a string using a regular expression based on pat.
+    ''' creates a pipeable function that will split a string using a regular expression based on pat.
     
     args:
         pat: a regular expression pattern used to split strings.
